@@ -200,6 +200,7 @@ def init():
                     print("Looking for Pull Opeartion")
                     time.sleep(60)
                     flag=flag+1
+                    print("1")
                     
                 else:
                     print("no files to pull")
@@ -207,6 +208,7 @@ def init():
                     flag=0
 
             curtime = datetime.datetime.now()
+            print("2")
 
             if flag > 0:
                 response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name,'Time ':curtime,'user_name':username,'message':"pull success",'status':'pull operation performed'})
@@ -214,7 +216,7 @@ def init():
             else:
                 response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name,'Time ':curtime,'user_name':username,'message': "pull failed",'status':'pull operation performed'})
 
-            print(response2)
+            print(response2.status_code)
            #success , project id , repo name , current date and time , email id'
     
 
